@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# Copyright (c) 2011-2023 Sullivan Beck.  All rights reserved.
+# Copyright (c) 2011-2025 Sullivan Beck.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -37,6 +37,9 @@ $Data{'langvar'}{'iana'}{'orig'}{'name'} = {
    "Latvian orthography used before 1920s (\"veca druka\")",
    "Lengua de señas Albarradas"      => "Lengua de senas Albarradas",
    "Østgrønlandsk"               => "Ostgronlandsk",
+   "Gherdëina standard of Ladin"  => "Ghereina standard of Ladin",
+   "Pe̍h-ōe-jī orthography/romanization" => "Peh-oe-ji orthography/romanization",
+   "Tâi-lô orthography/romanization" => "Tai-lo orthography/romanization",
 };
 
 $Data{'langvar'}{'iana'}{'ignore'} = {
